@@ -15,7 +15,7 @@ impl Tokenizer for BPETokenizer {
         use serde_json::Value;
         // Create token2index map
         // Open vocab file
-        let json: HashMap<String, Value> = serde_json::from_str(&include_str!("../resources/bpe_vocab.json").replace("/", "").replace("Ġ", "")).expect("Error parsing BPE vocab file!");
+        let json: HashMap<String, Value> = serde_json::from_str(&include_str!("../resources/bpe_vocab.json").replace('/', "").replace('Ġ', "")).expect("Error parsing BPE vocab file!");
         // Build sorted vector of tokens from hashmap
         let mut token_vec: Vec<String> = vec![String::from(""); 50265]; // Happen to know the largest index in the json is 50264, this is a bad system
         for token in json.keys() {
@@ -33,7 +33,7 @@ impl Tokenizer for BPETokenizer {
         let mut merges: Vec<(String, String)> = Vec::new();
         let lines: Vec<&str> = include_str!("../resources/bpe_merges.txt").split('\n').collect();
         for line in lines {
-            let line = String::from(line).replace("Ġ", "").replace("\n", "").replace("##", "");
+            let line = String::from(line).replace('Ġ', "").replace('\n', "").replace("##", "");
             // Filter out junk
             if line.contains(' ') && !line.contains('#') {
                 let line: Vec<&str> = line.split(' ').collect();
